==> haskell-libmpd-0.9.0.8-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libmpd
version: 0.9.0.8
id: libmpd-0.9.0.8-E8ZIi1iG0An6u1n3qsRPpb
key: libmpd-0.9.0.8-E8ZIi1iG0An6u1n3qsRPpb
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
author: Ben Sinclair
exposed: True
indefinite: False
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
abi: 628f0b9dfe13d2d985f34c5d257be799
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libmpd-0.9.0.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/libmpd-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/libmpd-0.9.0.8
hs-libraries: HSlibmpd-0.9.0.8-E8ZIi1iG0An6u1n3qsRPpb
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15
    bytestring-0.10.8.2 containers-0.5.10.2 filepath-1.4.1.2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5
    network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO time-1.8.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=59d0190781dd74e9cf2161eb5998f2f1
             network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT=3bb40bf00d3257de945a134963a298b0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
haddock-interfaces: /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html: /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libmpd-0.9.0.8-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libmpd
version: 0.9.0.8
id: libmpd-0.9.0.8-gtyuGyiHvIHsc52yvFDcI
key: libmpd-0.9.0.8-gtyuGyiHvIHsc52yvFDcI
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
author: Ben Sinclair
exposed: True
indefinite: False
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
abi: 457a636a9d718f19930d95d37caad2c0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libmpd-0.9.0.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/libmpd-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/libmpd-0.9.0.8
hs-libraries: HSlibmpd-0.9.0.8-gtyuGyiHvIHsc52yvFDcI
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15
    bytestring-0.10.8.2 containers-0.5.10.2 filepath-1.4.1.2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5
    network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO time-1.8.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=59d0190781dd74e9cf2161eb5998f2f1
             network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ=82fe21e10301e2e4d8701392ba21a740
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
haddock-interfaces: /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html: /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
